/*
 *
 * Copyright (c) 1998 Scott Oaks. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and
 * without fee is hereby granted.
 *
 * This sample source code is provided for example only,
 * on an unsupported, as-is basis. 
 *
 * AUTHOR MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. AUTHOR SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * THIS SOFTWARE IS NOT DESIGNED OR INTENDED FOR USE OR RESALE AS ON-LINE
 * CONTROL EQUIPMENT IN HAZARDOUS ENVIRONMENTS REQUIRING FAIL-SAFE
 * PERFORMANCE, SUCH AS IN THE OPERATION OF NUCLEAR FACILITIES, AIRCRAFT
 * NAVIGATION OR COMMUNICATION SYSTEMS, AIR TRAFFIC CONTROL, DIRECT LIFE
 * SUPPORT MACHINES, OR WEAPONS SYSTEMS, IN WHICH THE FAILURE OF THE
 * SOFTWARE COULD LEAD DIRECTLY TO DEATH, PERSONAL INJURY, OR SEVERE
 * PHYSICAL OR ENVIRONMENTAL DAMAGE ("HIGH RISK ACTIVITIES").  AUTHOR
 * SPECIFICALLY DISCLAIMS ANY EXPRESS OR IMPLIED WARRANTY OF FITNESS FOR
 * HIGH RISK ACTIVITIES.
 */


import java.security.*;

public class XYZIdentity extends Identity implements XYZTrust {
	private int trustLevel;

	protected XYZIdentity() {
	}

	public XYZIdentity(String name, IdentityScope scope)
								throws KeyManagementException {
		super(name, scope);
		scope.addIdentity(this);
		trustLevel = 0;
	}

	public void setPublicKey(PublicKey key) throws KeyManagementException {
		IdentityScope is = getScope();
		Identity i = is.getIdentity(key);
		if (i != null && !equals(i))
			throw new KeyManagementException("Duplicate public key");
		super.setPublicKey(key);
	}

	public void addCertificate(Certificate cert) throws KeyManagementException {
		Identity i = getScope().getIdentity(cert.getPublicKey());
		if (i != null && !equals(i))
			throw new KeyManagementException("Duplicate public key");
		super.addCertificate(cert);
	}

	public int getTrust() {
		return trustLevel;
	}

	void setTrust(int x) {
		if (x < 0 || x > 10)
			throw new IllegalArgumentException("Invalid trust level");
		trustLevel = x;
	}

	public String toString() {
		return super.toString() + " trust level: " + trustLevel;
	}
}
